Republican N.J. senator rips Christie over State of the State speech | NJ.com
Description: State Sen. Michael Doherty (R-Warren) today ripped Gov. Chris Christie as having done nothing to change the state's status quo or help its urban and suburban communities

comments

# Republican N.J. senator rips Christie over State of the State speech

New Jersey Supreme Court hearings
Senator Michael Doherty, shown questioning state Supreme Court Justice Stuart Rabner during his june confirmation hearing, today ripped into Gov. Chris Christie over his State of the State speech (Ed Murray/The Star-Ledger)
Print
Matt Friedman | NJ Advance Media for NJ.com By Matt Friedman | NJ Advance Media for NJ.com The Star-Ledger
Email the author | Follow on Twitter
on January 14, 2015 at 2:30 PM, updated January 14, 2015 at 3:55 PM
View/Post Comments

TRENTON — Gov. Chris Christie’s State of the State speech on Tuesday pushed one of New Jersey’s most conservative state senators over the edge, leading to the harshest criticism of the governor ever from a Republican state lawmaker.
State Sen. Michael Doherty (R-Warren) said Christie when he first ran in 2009 “sold himself to the people of New Jersey that he was going to change it.”
“And he didn’t,” Doherty said in a phone interview.
“The governor’s possible national ambitions have distracted him from doing the job he was hired to do in the State of New Jersey,” he said.
In an interview with PolitickerNJ.com published this morning, Doherty was quoted calling Christie a “failed” governor. Asked about it by NJ Advance Media, Doherty declined to repeat that exact word. But he nonetheless offered a scorching review of Christie’s speech — in particular his focus on Camden.
“I don’t know that I particularly said the word ‘failed,’” Doherty said. “What I said was that Gov. Christie has missed his opportunity to make a great mark on the State of New Jersey.”
Most New Jersey Republicans have been loath to publicly criticize Christie, and many on Tuesday issued statements praising his speech and record. State Sen. Dawn Addiego (R-Burlington), for example, said Christie "has dedicated his efforts to make New Jersey affordable and to provide opportunity for the families who live here."

And Doherty has been the most critical of Christie among Republican lawmakers in the past. He is the only Republican who has so far agreed to vote to override Christie’s veto of a bill to overhaul the Port Authority. And Doherty in 2009 also supported Christie's primary rival for the GOP nomination for governor, Steve Lonegan.

Still, Doherty’s past comments were restrained compared to the torrent he released today.
Doherty, who represents a largely rural district, says his main frustration is that New Jersey’s poor, urban school districts are still getting a disproportionate amount of state aid thanks to a series of Supreme Court decisions dating back to the 1970s known as Abbott v. Burke.

Chris Christie’s 2015 State of the State: ignoring the big issues facing NJ? NJ Advance Media commentator Brian Donohue and Star-Ledger editorial page editor Tom Moran discuss New Jersey Gov. Chris Christie’s 2015 State of the State address, with Moran echoing the criticism that the speech ignored the big issues facing New Jersey and was instead an attempt to launch Christie’s presidential run. (Video by Brian Donohue | NJ Advance Media for NJ.com)

"For him yesterday to hold up Camden County government as an example of what we should all be? Give me a break. It’s one of the most wasteful and corrupt governments in the State of New Jersey," Doherty said. "How long can the suburban and rural towns be told keep funneling your money into the cities, we’re just around the corner, everything’s going to recover and everything’s going to come back to normal?"
Doherty was particularly angry that Hoboken— once impoverished but now a wealthy New York City bedroom community — is still considered an “Abbott district” and has state-funded universal pre-K. (One town in Doherty’s district, Phillipsburg, is also an Abbott district).
“We’re struggling tremendously. Houses in my district are selling for less than they did a quarter century ago. There has been no economic recovery. We’re getting our clocks cleaned by Pennslyvania. They’re so close,” Doherty said. “We need help.”
Christie was critical of those decisions during his first run for governor in 2009. And while that led to some battles with Democrats who control the state Senate over Supreme Court nominees, Doherty said Christie “didn’t fight hard enough” to change the court’s makeup.
For instance, Doherty noted that Christie declined to re-nominate former Justice Helen Hoens to the bench.
“The one justice that wrote an opinion that all of us in the suburbs and rural areas agree with regarding school funding and challenging the urban areas to do better than they had was Justice Helen Hoens,” Doherty said.
Doherty said Christie’s appeal to New Jersey’s urban mayors to follow his example of working with Camden to overhaul its police force and attract businesses with economic incentives underscored his feeling that he was ignoring the state’s suburban and rural areas.
“I was very alarmed when Gov. Christie said to be ‘Big cities, come to me and we’re rebuild you,” Doherty said. “When does it ever end? These suburban areas of New Jersey are struggling tremendously. They never recovered from the Great Recession. And we’re told keep sending the money in.”
Doherty said Christie has “did not follow through his promise to fight the corruption and break up the status quo.”
There are some political undercurrents in Doherty's criticism. Doherty was a supporter of U.S. Rep. Ron Paul’s campaigns for the Republican presidential nomination in 2008 and 2012. Paul’s son, U.S. Sen. Rand Paul of Kentucky, is considered a likely presidential candidate in 2016. But Doherty said that had nothing to do with his criticism.
“I’m not supporting anybody at this point,” he said.

A spokesman for Christie declined to comment.

Loading Photo Gallery

## MORE POLITICS

Matt Friedman may be reached at mfriedman@njadvancemedia.com. Follow him on Twitter @MattFriedmanSL. Find NJ.com on Facebook.

View/Post Comments

## Related Stories

## Most Read

# Video of the Day

## Inside Jersey: Best Home Chefs 2015

# N.J. Politics News In Your Inbox

From Christie to Booker, get your daily N.J. politics fix.
optional
Check here if you do not want to receive additional email offers and information. See our privacy policy

# Thank you for your subscription!

To view and subscribe to any of our other newsletters, please click here.

# Political Viewpoints

- Tom Moran's latest columns
- Paul Mulshine's latest columns
- Editorials from The Star-Ledger

# Trending Videos

## Active Discussions

## Best of NJ.com

Edison mayor's son arrested on drug charges
Snow, sleet possible for parts of New Jersey
5 things Christie didn't discuss in State of State